# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/folder_budget_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/folder_budget_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/datasphere/v1/folder_budget_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\x16GetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xc3\x01\n\x17GetFolderBudgetResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x91\x02\n\x16SetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x08set_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x0cunit_balance\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value2\xc3\x02\n\x13\x46olderBudgetService\x12\xa1\x01\n\x03Get\x12\x32.yandex.cloud.datasphere.v1.GetFolderBudgetRequest\x1a\x33.yandex.cloud.datasphere.v1.GetFolderBudgetResponse\"1\x82\xd3\xe4\x93\x02+\x12)/datasphere/v1/folders/{folder_id}:budget\x12\x87\x01\n\x03Set\x12\x32.yandex.cloud.datasphere.v1.SetFolderBudgetRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\")/datasphere/v1/folders/{folder_id}:budget:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETFOLDERBUDGETREQUEST = _descriptor.Descriptor(
  name='GetFolderBudgetRequest',
  full_name='yandex.cloud.datasphere.v1.GetFolderBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.GetFolderBudgetRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=299,
)


_GETFOLDERBUDGETRESPONSE = _descriptor.Descriptor(
  name='GetFolderBudgetResponse',
  full_name='yandex.cloud.datasphere.v1.GetFolderBudgetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_balance', full_name='yandex.cloud.datasphere.v1.GetFolderBudgetResponse.unit_balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_units_per_hour', full_name='yandex.cloud.datasphere.v1.GetFolderBudgetResponse.max_units_per_hour', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_units_per_execution', full_name='yandex.cloud.datasphere.v1.GetFolderBudgetResponse.max_units_per_execution', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=497,
)


_SETFOLDERBUDGETREQUEST = _descriptor.Descriptor(
  name='SetFolderBudgetRequest',
  full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_mask', full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest.set_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_balance', full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest.unit_balance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_units_per_hour', full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest.max_units_per_hour', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_units_per_execution', full_name='yandex.cloud.datasphere.v1.SetFolderBudgetRequest.max_units_per_execution', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=773,
)

_GETFOLDERBUDGETRESPONSE.fields_by_name['unit_balance'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GETFOLDERBUDGETRESPONSE.fields_by_name['max_units_per_hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GETFOLDERBUDGETRESPONSE.fields_by_name['max_units_per_execution'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SETFOLDERBUDGETREQUEST.fields_by_name['set_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_SETFOLDERBUDGETREQUEST.fields_by_name['unit_balance'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SETFOLDERBUDGETREQUEST.fields_by_name['max_units_per_hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SETFOLDERBUDGETREQUEST.fields_by_name['max_units_per_execution'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['GetFolderBudgetRequest'] = _GETFOLDERBUDGETREQUEST
DESCRIPTOR.message_types_by_name['GetFolderBudgetResponse'] = _GETFOLDERBUDGETRESPONSE
DESCRIPTOR.message_types_by_name['SetFolderBudgetRequest'] = _SETFOLDERBUDGETREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFolderBudgetRequest = _reflection.GeneratedProtocolMessageType('GetFolderBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFOLDERBUDGETREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.folder_budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetFolderBudgetRequest)
  })
_sym_db.RegisterMessage(GetFolderBudgetRequest)

GetFolderBudgetResponse = _reflection.GeneratedProtocolMessageType('GetFolderBudgetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFOLDERBUDGETRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.folder_budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetFolderBudgetResponse)
  })
_sym_db.RegisterMessage(GetFolderBudgetResponse)

SetFolderBudgetRequest = _reflection.GeneratedProtocolMessageType('SetFolderBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETFOLDERBUDGETREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.folder_budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.SetFolderBudgetRequest)
  })
_sym_db.RegisterMessage(SetFolderBudgetRequest)


DESCRIPTOR._options = None
_GETFOLDERBUDGETREQUEST.fields_by_name['folder_id']._options = None
_SETFOLDERBUDGETREQUEST.fields_by_name['folder_id']._options = None

_FOLDERBUDGETSERVICE = _descriptor.ServiceDescriptor(
  name='FolderBudgetService',
  full_name='yandex.cloud.datasphere.v1.FolderBudgetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=776,
  serialized_end=1099,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.datasphere.v1.FolderBudgetService.Get',
    index=0,
    containing_service=None,
    input_type=_GETFOLDERBUDGETREQUEST,
    output_type=_GETFOLDERBUDGETRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/datasphere/v1/folders/{folder_id}:budget',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='yandex.cloud.datasphere.v1.FolderBudgetService.Set',
    index=1,
    containing_service=None,
    input_type=_SETFOLDERBUDGETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002.\")/datasphere/v1/folders/{folder_id}:budget:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FOLDERBUDGETSERVICE)

DESCRIPTOR.services_by_name['FolderBudgetService'] = _FOLDERBUDGETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/lockbox/v1/secret.proto',
  package='yandex.cloud.lockbox.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$yandex/cloud/lockbox/v1/secret.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd4\x03\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12;\n\x06labels\x18\x06 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.Secret.LabelsEntry\x12\x12\n\nkms_key_id\x18\x07 \x01(\t\x12\x36\n\x06status\x18\x08 \x01(\x0e\x32&.yandex.cloud.lockbox.v1.Secret.Status\x12\x39\n\x0f\x63urrent_version\x18\t \x01(\x0b\x32 .yandex.cloud.lockbox.v1.Version\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\"\xce\x02\n\x07Version\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndestroy_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x37\n\x06status\x18\x06 \x01(\x0e\x32\'.yandex.cloud.lockbox.v1.Version.Status\x12\x1a\n\x12payload_entry_keys\x18\x07 \x03(\t\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03\x42\x62\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SECRET_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.lockbox.v1.Secret.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=495,
  serialized_end=567,
)
_sym_db.RegisterEnumDescriptor(_SECRET_STATUS)

_VERSION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.lockbox.v1.Version.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED_FOR_DESTRUCTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESTROYED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=814,
  serialized_end=904,
)
_sym_db.RegisterEnumDescriptor(_VERSION_STATUS)


_SECRET_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.lockbox.v1.Secret.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.lockbox.v1.Secret.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.lockbox.v1.Secret.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=493,
)

_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='yandex.cloud.lockbox.v1.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.lockbox.v1.Secret.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.lockbox.v1.Secret.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.lockbox.v1.Secret.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.lockbox.v1.Secret.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.lockbox.v1.Secret.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.lockbox.v1.Secret.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kms_key_id', full_name='yandex.cloud.lockbox.v1.Secret.kms_key_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.lockbox.v1.Secret.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_version', full_name='yandex.cloud.lockbox.v1.Secret.current_version', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.lockbox.v1.Secret.deletion_protection', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SECRET_LABELSENTRY, ],
  enum_types=[
    _SECRET_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=567,
)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='yandex.cloud.lockbox.v1.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.lockbox.v1.Version.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_id', full_name='yandex.cloud.lockbox.v1.Version.secret_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.lockbox.v1.Version.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destroy_at', full_name='yandex.cloud.lockbox.v1.Version.destroy_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.lockbox.v1.Version.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.lockbox.v1.Version.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_entry_keys', full_name='yandex.cloud.lockbox.v1.Version.payload_entry_keys', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VERSION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=904,
)

_SECRET_LABELSENTRY.containing_type = _SECRET
_SECRET.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SECRET.fields_by_name['labels'].message_type = _SECRET_LABELSENTRY
_SECRET.fields_by_name['status'].enum_type = _SECRET_STATUS
_SECRET.fields_by_name['current_version'].message_type = _VERSION
_SECRET_STATUS.containing_type = _SECRET
_VERSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VERSION.fields_by_name['destroy_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VERSION.fields_by_name['status'].enum_type = _VERSION_STATUS
_VERSION_STATUS.containing_type = _VERSION
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SECRET_LABELSENTRY,
    '__module__' : 'yandex.cloud.lockbox.v1.secret_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.lockbox.v1.Secret.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'yandex.cloud.lockbox.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.lockbox.v1.Secret)
  })
_sym_db.RegisterMessage(Secret)
_sym_db.RegisterMessage(Secret.LabelsEntry)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'yandex.cloud.lockbox.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.lockbox.v1.Version)
  })
_sym_db.RegisterMessage(Version)


DESCRIPTOR._options = None
_SECRET_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# coding: utf-8

import semantic_release
from semantic_release.history import parser_angular, parser_helpers


def parse_commit(message):
    if (
        "generated by python-semantic-release" in message
        or message.startswith("Merge pull request")
        or message.startswith("Merge branch")
    ):
        raise semantic_release.UnknownCommitMessageStyleError()

    return parser_helpers.ParsedCommit(
        bump=parser_angular.LEVEL_BUMPS["minor"],
        type="feature",
        scope=None,
        descriptions=[message],
        breaking_descriptions=[],
    )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.datasphere.v1 import project_data_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2


class ProjectDataServiceStub(object):
    """A set of methods for managing data of the Project resource.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UploadFile = channel.stream_unary(
                '/yandex.cloud.datasphere.v1.ProjectDataService/UploadFile',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileResponse.FromString,
                )
        self.DownloadFile = channel.unary_stream(
                '/yandex.cloud.datasphere.v1.ProjectDataService/DownloadFile',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileResponse.FromString,
                )


class ProjectDataServiceServicer(object):
    """A set of methods for managing data of the Project resource.
    """

    def UploadFile(self, request_iterator, context):
        """Uploads a file to the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Downloads the specified file from the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileResponse.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v1.ProjectDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectDataService(object):
    """A set of methods for managing data of the Project resource.
    """

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/yandex.cloud.datasphere.v1.ProjectDataService/UploadFile',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.UploadFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.datasphere.v1.ProjectDataService/DownloadFile',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__data__service__pb2.DownloadFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import database_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ydb/v1/database_service.proto',
  package='yandex.cloud.ydb.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/ydb/v1/database_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\"yandex/cloud/ydb/v1/database.proto\x1a yandex/cloud/ydb/v1/backup.proto\"\x89\x01\n\x14RestoreBackupRequest\x12\x1f\n\tbackup_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x64\x61tabase_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10paths_to_restore\x18\x03 \x03(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\"?\n\x15RestoreBackupMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"j\n\x15\x42\x61\x63kupDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12<\n\x0f\x62\x61\x63kup_settings\x18\x02 \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\"@\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"9\n\x14StartDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x15StartDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"8\n\x13StopDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x14StopDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"7\n\x12GetDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"g\n\x14ListDatabasesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListDatabasesResponse\x12\x30\n\tdatabases\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.ydb.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc9\x06\n\x15\x43reateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x04 \x01(\t\x12:\n\x0estorage_config\x18\x05 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x12\n\nsubnet_ids\x18\x08 \x03(\t\x12<\n\x0ezonal_database\x18\t \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\n \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\r \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x0e \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x0b \x01(\x08\x12\x13\n\x0blocation_id\x18\x0c \x01(\t\x12\x46\n\x06labels\x18\x0f \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x10 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x11 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16\x43reateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\x8f\x07\n\x15UpdateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x61tabase_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x06 \x01(\t\x12:\n\x0estorage_config\x18\x07 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x08 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12\x12\n\nsubnet_ids\x18\n \x03(\t\x12<\n\x0ezonal_database\x18\x0b \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0c \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x0f \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x10 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\r \x01(\x08\x12\x13\n\x0blocation_id\x18\x0e \x01(\t\x12\x46\n\x06labels\x18\x11 \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x12 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x13 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16UpdateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\",\n\x15\x44\x65leteDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\"D\n\x16\x44\x65leteDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\xef\x0e\n\x0f\x44\x61tabaseService\x12v\n\x03Get\x12\'.yandex.cloud.ydb.v1.GetDatabaseRequest\x1a\x1d.yandex.cloud.ydb.v1.Database\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/ydb/v1/databases/{database_id}\x12x\n\x04List\x12).yandex.cloud.ydb.v1.ListDatabasesRequest\x1a*.yandex.cloud.ydb.v1.ListDatabasesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/ydb/v1/databases\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.ydb.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"B\x82\xd3\xe4\x93\x02\x16\"\x11/ydb/v1/databases:\x01*\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.ydb.v1.UpdateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\x82\xd3\xe4\x93\x02$2\x1f/ydb/v1/databases/{database_id}:\x01*\xb2\xd2*\"\n\x16UpdateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xa9\x01\n\x05Start\x12).yandex.cloud.ydb.v1.StartDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02\'\"%/ydb/v1/databases/{database_id}:start\xb2\xd2*!\n\x15StartDatabaseMetadata\x12\x08\x44\x61tabase\x12\xa5\x01\n\x04Stop\x12(.yandex.cloud.ydb.v1.StopDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\x82\xd3\xe4\x93\x02&\"$/ydb/v1/databases/{database_id}:stop\xb2\xd2* \n\x14StopDatabaseMetadata\x12\x08\x44\x61tabase\x12u\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\x12\xa4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xad\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.ydb.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02!*\x1f/ydb/v1/databases/{database_id}\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x12\xa2\x01\n\x07Restore\x12).yandex.cloud.ydb.v1.RestoreBackupRequest\x1a!.yandex.cloud.operation.Operation\"I\x82\xd3\xe4\x93\x02\x1e\"\x19/ydb/v1/databases:restore:\x01*\xb2\xd2*!\n\x15RestoreBackupMetadata\x12\x08\x44\x61tabase\x12\xa2\x01\n\x06\x42\x61\x63kup\x12*.yandex.cloud.ydb.v1.BackupDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"I\x82\xd3\xe4\x93\x02\x1d\"\x18/ydb/v1/databases:backup:\x01*\xb2\xd2*\"\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x08\x44\x61tabaseBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2.DESCRIPTOR,])




_RESTOREBACKUPREQUEST = _descriptor.Descriptor(
  name='RestoreBackupRequest',
  full_name='yandex.cloud.ydb.v1.RestoreBackupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.ydb.v1.RestoreBackupRequest.backup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.RestoreBackupRequest.database_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paths_to_restore', full_name='yandex.cloud.ydb.v1.RestoreBackupRequest.paths_to_restore', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_path', full_name='yandex.cloud.ydb.v1.RestoreBackupRequest.target_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=478,
)


_RESTOREBACKUPMETADATA = _descriptor.Descriptor(
  name='RestoreBackupMetadata',
  full_name='yandex.cloud.ydb.v1.RestoreBackupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.ydb.v1.RestoreBackupMetadata.backup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.RestoreBackupMetadata.database_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=543,
)


_BACKUPDATABASEREQUEST = _descriptor.Descriptor(
  name='BackupDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.BackupDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.BackupDatabaseRequest.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_settings', full_name='yandex.cloud.ydb.v1.BackupDatabaseRequest.backup_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=651,
)


_BACKUPDATABASEMETADATA = _descriptor.Descriptor(
  name='BackupDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.BackupDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.ydb.v1.BackupDatabaseMetadata.backup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.BackupDatabaseMetadata.database_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=717,
)


_STARTDATABASEREQUEST = _descriptor.Descriptor(
  name='StartDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.StartDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.StartDatabaseRequest.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=776,
)


_STARTDATABASEMETADATA = _descriptor.Descriptor(
  name='StartDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.StartDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.StartDatabaseMetadata.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.ydb.v1.StartDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=845,
)


_STOPDATABASEREQUEST = _descriptor.Descriptor(
  name='StopDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.StopDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.StopDatabaseRequest.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=903,
)


_STOPDATABASEMETADATA = _descriptor.Descriptor(
  name='StopDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.StopDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.StopDatabaseMetadata.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.ydb.v1.StopDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=971,
)


_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.GetDatabaseRequest.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1028,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='yandex.cloud.ydb.v1.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ydb.v1.ListDatabasesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.ydb.v1.ListDatabasesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.ydb.v1.ListDatabasesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1133,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yandex.cloud.ydb.v1.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yandex.cloud.ydb.v1.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.ydb.v1.ListDatabasesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1233,
)


_CREATEDATABASEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2015,
  serialized_end=2060,
)

_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.resource_preset_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.storage_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.scale_policy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.network_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.subnet_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zonal_database', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.zonal_database', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regional_database', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.regional_database', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated_database', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.dedicated_database', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_database', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.serverless_database', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ips', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.assign_public_ips', index=12,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.location_id', index=13,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.labels', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_config', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.backup_config', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_config', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.monitoring_config', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDATABASEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='database_type', full_name='yandex.cloud.ydb.v1.CreateDatabaseRequest.database_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1236,
  serialized_end=2077,
)


_CREATEDATABASEMETADATA = _descriptor.Descriptor(
  name='CreateDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.CreateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.CreateDatabaseMetadata.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.ydb.v1.CreateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2079,
  serialized_end=2147,
)


_UPDATEDATABASEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2015,
  serialized_end=2060,
)

_UPDATEDATABASEREQUEST = _descriptor.Descriptor(
  name='UpdateDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.database_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.resource_preset_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.storage_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.scale_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.network_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.subnet_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zonal_database', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.zonal_database', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regional_database', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.regional_database', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated_database', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.dedicated_database', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_database', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.serverless_database', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ips', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.assign_public_ips', index=14,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.location_id', index=15,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.labels', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_config', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.backup_config', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_config', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.monitoring_config', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEDATABASEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='database_type', full_name='yandex.cloud.ydb.v1.UpdateDatabaseRequest.database_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2150,
  serialized_end=3061,
)


_UPDATEDATABASEMETADATA = _descriptor.Descriptor(
  name='UpdateDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.UpdateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.UpdateDatabaseMetadata.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.ydb.v1.UpdateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3063,
  serialized_end=3131,
)


_DELETEDATABASEREQUEST = _descriptor.Descriptor(
  name='DeleteDatabaseRequest',
  full_name='yandex.cloud.ydb.v1.DeleteDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.DeleteDatabaseRequest.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3133,
  serialized_end=3177,
)


_DELETEDATABASEMETADATA = _descriptor.Descriptor(
  name='DeleteDatabaseMetadata',
  full_name='yandex.cloud.ydb.v1.DeleteDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_id', full_name='yandex.cloud.ydb.v1.DeleteDatabaseMetadata.database_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.ydb.v1.DeleteDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3179,
  serialized_end=3247,
)

_BACKUPDATABASEREQUEST.fields_by_name['backup_settings'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2._BACKUPSETTINGS
_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._DATABASE
_CREATEDATABASEREQUEST_LABELSENTRY.containing_type = _CREATEDATABASEREQUEST
_CREATEDATABASEREQUEST.fields_by_name['storage_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._STORAGECONFIG
_CREATEDATABASEREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._SCALEPOLICY
_CREATEDATABASEREQUEST.fields_by_name['zonal_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._ZONALDATABASE
_CREATEDATABASEREQUEST.fields_by_name['regional_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._REGIONALDATABASE
_CREATEDATABASEREQUEST.fields_by_name['dedicated_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._DEDICATEDDATABASE
_CREATEDATABASEREQUEST.fields_by_name['serverless_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._SERVERLESSDATABASE
_CREATEDATABASEREQUEST.fields_by_name['labels'].message_type = _CREATEDATABASEREQUEST_LABELSENTRY
_CREATEDATABASEREQUEST.fields_by_name['backup_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2._BACKUPCONFIG
_CREATEDATABASEREQUEST.fields_by_name['monitoring_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._MONITORINGCONFIG
_CREATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['zonal_database'])
_CREATEDATABASEREQUEST.fields_by_name['zonal_database'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['database_type']
_CREATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['regional_database'])
_CREATEDATABASEREQUEST.fields_by_name['regional_database'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['database_type']
_CREATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['dedicated_database'])
_CREATEDATABASEREQUEST.fields_by_name['dedicated_database'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['database_type']
_CREATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['serverless_database'])
_CREATEDATABASEREQUEST.fields_by_name['serverless_database'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['database_type']
_UPDATEDATABASEREQUEST_LABELSENTRY.containing_type = _UPDATEDATABASEREQUEST
_UPDATEDATABASEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDATABASEREQUEST.fields_by_name['storage_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._STORAGECONFIG
_UPDATEDATABASEREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._SCALEPOLICY
_UPDATEDATABASEREQUEST.fields_by_name['zonal_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._ZONALDATABASE
_UPDATEDATABASEREQUEST.fields_by_name['regional_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._REGIONALDATABASE
_UPDATEDATABASEREQUEST.fields_by_name['dedicated_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._DEDICATEDDATABASE
_UPDATEDATABASEREQUEST.fields_by_name['serverless_database'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._SERVERLESSDATABASE
_UPDATEDATABASEREQUEST.fields_by_name['labels'].message_type = _UPDATEDATABASEREQUEST_LABELSENTRY
_UPDATEDATABASEREQUEST.fields_by_name['backup_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2._BACKUPCONFIG
_UPDATEDATABASEREQUEST.fields_by_name['monitoring_config'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._MONITORINGCONFIG
_UPDATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _UPDATEDATABASEREQUEST.fields_by_name['zonal_database'])
_UPDATEDATABASEREQUEST.fields_by_name['zonal_database'].containing_oneof = _UPDATEDATABASEREQUEST.oneofs_by_name['database_type']
_UPDATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _UPDATEDATABASEREQUEST.fields_by_name['regional_database'])
_UPDATEDATABASEREQUEST.fields_by_name['regional_database'].containing_oneof = _UPDATEDATABASEREQUEST.oneofs_by_name['database_type']
_UPDATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _UPDATEDATABASEREQUEST.fields_by_name['dedicated_database'])
_UPDATEDATABASEREQUEST.fields_by_name['dedicated_database'].containing_oneof = _UPDATEDATABASEREQUEST.oneofs_by_name['database_type']
_UPDATEDATABASEREQUEST.oneofs_by_name['database_type'].fields.append(
  _UPDATEDATABASEREQUEST.fields_by_name['serverless_database'])
_UPDATEDATABASEREQUEST.fields_by_name['serverless_database'].containing_oneof = _UPDATEDATABASEREQUEST.oneofs_by_name['database_type']
DESCRIPTOR.message_types_by_name['RestoreBackupRequest'] = _RESTOREBACKUPREQUEST
DESCRIPTOR.message_types_by_name['RestoreBackupMetadata'] = _RESTOREBACKUPMETADATA
DESCRIPTOR.message_types_by_name['BackupDatabaseRequest'] = _BACKUPDATABASEREQUEST
DESCRIPTOR.message_types_by_name['BackupDatabaseMetadata'] = _BACKUPDATABASEMETADATA
DESCRIPTOR.message_types_by_name['StartDatabaseRequest'] = _STARTDATABASEREQUEST
DESCRIPTOR.message_types_by_name['StartDatabaseMetadata'] = _STARTDATABASEMETADATA
DESCRIPTOR.message_types_by_name['StopDatabaseRequest'] = _STOPDATABASEREQUEST
DESCRIPTOR.message_types_by_name['StopDatabaseMetadata'] = _STOPDATABASEMETADATA
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseMetadata'] = _CREATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['UpdateDatabaseRequest'] = _UPDATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatabaseMetadata'] = _UPDATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['DeleteDatabaseRequest'] = _DELETEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatabaseMetadata'] = _DELETEDATABASEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RestoreBackupRequest = _reflection.GeneratedProtocolMessageType('RestoreBackupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREBACKUPREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.RestoreBackupRequest)
  })
_sym_db.RegisterMessage(RestoreBackupRequest)

RestoreBackupMetadata = _reflection.GeneratedProtocolMessageType('RestoreBackupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREBACKUPMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.RestoreBackupMetadata)
  })
_sym_db.RegisterMessage(RestoreBackupMetadata)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

BackupDatabaseMetadata = _reflection.GeneratedProtocolMessageType('BackupDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.BackupDatabaseMetadata)
  })
_sym_db.RegisterMessage(BackupDatabaseMetadata)

StartDatabaseRequest = _reflection.GeneratedProtocolMessageType('StartDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StartDatabaseRequest)
  })
_sym_db.RegisterMessage(StartDatabaseRequest)

StartDatabaseMetadata = _reflection.GeneratedProtocolMessageType('StartDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StartDatabaseMetadata)
  })
_sym_db.RegisterMessage(StartDatabaseMetadata)

StopDatabaseRequest = _reflection.GeneratedProtocolMessageType('StopDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StopDatabaseRequest)
  })
_sym_db.RegisterMessage(StopDatabaseRequest)

StopDatabaseMetadata = _reflection.GeneratedProtocolMessageType('StopDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.StopDatabaseMetadata)
  })
_sym_db.RegisterMessage(StopDatabaseMetadata)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATABASEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)
_sym_db.RegisterMessage(CreateDatabaseRequest.LabelsEntry)

CreateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('CreateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.CreateDatabaseMetadata)
  })
_sym_db.RegisterMessage(CreateDatabaseMetadata)

UpdateDatabaseRequest = _reflection.GeneratedProtocolMessageType('UpdateDatabaseRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDATABASEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.UpdateDatabaseRequest)
  })
_sym_db.RegisterMessage(UpdateDatabaseRequest)
_sym_db.RegisterMessage(UpdateDatabaseRequest.LabelsEntry)

UpdateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('UpdateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.UpdateDatabaseMetadata)
  })
_sym_db.RegisterMessage(UpdateDatabaseMetadata)

DeleteDatabaseRequest = _reflection.GeneratedProtocolMessageType('DeleteDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.DeleteDatabaseRequest)
  })
_sym_db.RegisterMessage(DeleteDatabaseRequest)

DeleteDatabaseMetadata = _reflection.GeneratedProtocolMessageType('DeleteDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.ydb.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.DeleteDatabaseMetadata)
  })
_sym_db.RegisterMessage(DeleteDatabaseMetadata)


DESCRIPTOR._options = None
_RESTOREBACKUPREQUEST.fields_by_name['backup_id']._options = None
_RESTOREBACKUPREQUEST.fields_by_name['database_id']._options = None
_STARTDATABASEREQUEST.fields_by_name['database_id']._options = None
_STOPDATABASEREQUEST.fields_by_name['database_id']._options = None
_GETDATABASEREQUEST.fields_by_name['database_id']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
_CREATEDATABASEREQUEST_LABELSENTRY._options = None
_UPDATEDATABASEREQUEST_LABELSENTRY._options = None

_DATABASESERVICE = _descriptor.ServiceDescriptor(
  name='DatabaseService',
  full_name='yandex.cloud.ydb.v1.DatabaseService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3250,
  serialized_end=5153,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2._DATABASE,
    serialized_options=b'\202\323\344\223\002!\022\037/ydb/v1/databases/{database_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.ydb.v1.DatabaseService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDATABASESREQUEST,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/ydb/v1/databases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/ydb/v1/databases:\001*\262\322*\"\n\026CreateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$2\037/ydb/v1/databases/{database_id}:\001*\262\322*\"\n\026UpdateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Start',
    index=4,
    containing_service=None,
    input_type=_STARTDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'\"%/ydb/v1/databases/{database_id}:start\262\322*!\n\025StartDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Stop',
    index=5,
    containing_service=None,
    input_type=_STOPDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&\"$/ydb/v1/databases/{database_id}:stop\262\322* \n\024StopDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.ydb.v1.DatabaseService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.ydb.v1.DatabaseService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.ydb.v1.DatabaseService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Delete',
    index=9,
    containing_service=None,
    input_type=_DELETEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!*\037/ydb/v1/databases/{database_id}\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Restore',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Restore',
    index=10,
    containing_service=None,
    input_type=_RESTOREBACKUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036\"\031/ydb/v1/databases:restore:\001*\262\322*!\n\025RestoreBackupMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Backup',
    full_name='yandex.cloud.ydb.v1.DatabaseService.Backup',
    index=11,
    containing_service=None,
    input_type=_BACKUPDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035\"\030/ydb/v1/databases:backup:\001*\262\322*\"\n\026BackupDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASESERVICE)

DESCRIPTOR.services_by_name['DatabaseService'] = _DATABASESERVICE

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import argparse
import logging
import time
from uuid import uuid4

import grpc
import yandexcloud
from yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2 import WriteImageProductUsageRequest
from yandex.cloud.marketplace.v1.metering.image_product_usage_service_pb2_grpc import ImageProductUsageServiceStub
from yandex.cloud.marketplace.v1.metering.usage_record_pb2 import UsageRecord


def build_product_usage_write_request(product_id, sku_id, quantity, timestamp=None, uuid=None):
    """Builds an image product usage write request."""

    usage_record = UsageRecord()

    # NOTE: Behaves like idempotency key. Should be unique to prevent duplicates.
    usage_record.uuid = str(uuid4()) if uuid is None else str(uuid)
    usage_record.sku_id = sku_id
    usage_record.quantity = int(quantity)

    # NOTE: UTC timezone
    usage_record.timestamp.seconds = int(time.time()) if timestamp is None else int(timestamp)

    request = WriteImageProductUsageRequest()

    request.product_id = product_id
    request.usage_records.extend([usage_record])

    return request


def business_logic(product_id, sku_id):
    """Example of service."""

    if product_id == 'Secure Firewall' and sku_id == 'Ingress network traffic':
        return 1 + 1

    if product_id == 'Secure Firewall' and sku_id == 'Egress network traffic':
        return 1 * 1

    return 0


def validate_write_response(response):

    # NOTE: Some usage records can be accepted or rejected. Please pay attention to the following fields:

    # response.rejected - list of rejected usage records
    # response.accepted - list of accepted usage records

    if len(response.rejected) > 0:
        error_msg = 'Unable to provide the service to customer. Rejected: %s, Accepted: %s.'
        raise ValueError(error_msg % (str(response.rejected), str(response.accepted)))
    elif len(response.accepted) == 0:
        error_msg = 'Unable to provide the service to customer. Got empty list of accepted metrics.'
        raise ValueError(error_msg)


def main(product_id, sku_id, quantity, timestamp=None, uuid=None):
    # NOTE: IAM token will be taken automatically from metadata agent of VM
    interceptor = yandexcloud.RetryInterceptor(max_retry_count=5, retriable_codes=[grpc.StatusCode.UNAVAILABLE])
    sdk = yandexcloud.SDK(interceptor=interceptor)
    service = sdk.client(ImageProductUsageServiceStub)
    request = build_product_usage_write_request(product_id, sku_id, quantity, timestamp, uuid)

    # Step 0. Ensure consumer has all permissions to use the product (validate_only=True)

    request.validate_only = True
    response = service.Write(request)

    validate_write_response(response)

    # Step 1. Provide your service to the customer

    business_logic(product_id, sku_id)

    # Step 2. Write the product usage to Yandex.Cloud API (validate_only=False)

    request.validate_only = False
    response = service.Write(request)

    validate_write_response(response)

    return response


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('--product-id', help='Marketplace image product ID', required=True)
    parser.add_argument('--sku-id', help='Marketplace image product SKU', required=True)
    parser.add_argument('--quantity', help='Usage quantity', required=True)
    parser.add_argument('--timestamp', help='Usage time', required=False)
    parser.add_argument('--uuid', help='Usage request unique identifier', required=False)

    args = parser.parse_args()

    print(main(
        args.product_id,
        args.sku_id,
        args.quantity,
        args.timestamp,
        args.uuid,
    ))



#!/usr/bin/env python3
import argparse
import json
import logging

import grpc

from yandex.cloud.compute.v1.image_service_pb2 import GetImageLatestByFamilyRequest
from yandex.cloud.compute.v1.image_service_pb2_grpc import ImageServiceStub
from yandex.cloud.compute.v1.instance_pb2 import IPV4, Instance
from yandex.cloud.compute.v1.instance_service_pb2 import (
    CreateInstanceRequest,
    ResourcesSpec,
    AttachedDiskSpec,
    NetworkInterfaceSpec,
    PrimaryAddressSpec,
    OneToOneNatSpec,
    DeleteInstanceRequest,
    CreateInstanceMetadata,
    DeleteInstanceMetadata,
)
from yandex.cloud.compute.v1.instance_service_pb2_grpc import InstanceServiceStub

import yandexcloud


def create_instance(sdk, folder_id, zone, name, subnet_id):
    image_service = sdk.client(ImageServiceStub)
    source_image = image_service.GetLatestByFamily(
        GetImageLatestByFamilyRequest(
            folder_id='standard-images',
            family='debian-9'
        )
    )
    subnet_id = subnet_id or sdk.helpers.get_subnet(folder_id, zone)
    instance_service = sdk.client(InstanceServiceStub)
    operation = instance_service.Create(CreateInstanceRequest(
        folder_id=folder_id,
        name=name,
        resources_spec=ResourcesSpec(
            memory=2 * 2 ** 30,
            cores=2,
            core_fraction=0,
        ),
        zone_id=zone,
        platform_id='standard-v1',
        boot_disk_spec=AttachedDiskSpec(
            auto_delete=True,
            disk_spec=AttachedDiskSpec.DiskSpec(
                type_id='network-hdd',
                size=20 * 2 ** 30,
                image_id=source_image.id,
            )
        ),
        network_interface_specs=[
            NetworkInterfaceSpec(
                subnet_id=subnet_id,
                primary_v4_address_spec=PrimaryAddressSpec(
                    one_to_one_nat_spec=OneToOneNatSpec(
                        ip_version=IPV4,
                    )
                )
            ),
        ],
        metadata={
            'metadata-key': 'metadata-value',
        },
    ))
    logging.info('Creating initiated')
    return operation


def delete_instance(sdk, instance_id):
    instance_service = sdk.client(InstanceServiceStub)
    return instance_service.Delete(
        DeleteInstanceRequest(instance_id=instance_id))


def main():
    logging.basicConfig(level=logging.INFO)
    arguments = parse_args()
    interceptor = yandexcloud.RetryInterceptor(max_retry_count=5, retriable_codes=[grpc.StatusCode.UNAVAILABLE])
    if arguments.token:
        sdk = yandexcloud.SDK(interceptor=interceptor, token=arguments.token)
    else:
        with open(arguments.sa_json_path) as infile:
            sdk = yandexcloud.SDK(interceptor=interceptor, service_account_key=json.load(infile))

    fill_missing_arguments(sdk, arguments)

    instance_id = None
    try:
        operation = create_instance(sdk, arguments.folder_id, arguments.zone, arguments.name, arguments.subnet_id)
        operation_result = sdk.wait_operation_and_get_result(
            operation,
            response_type=Instance,
            meta_type=CreateInstanceMetadata,
        )

        instance_id = operation_result.response.id

    finally:
        if instance_id:
            logging.info('Deleting instance {}'.format(instance_id))
            operation = delete_instance(sdk, instance_id)
            sdk.wait_operation_and_get_result(
                operation,
                meta_type=DeleteInstanceMetadata,
            )


def fill_missing_arguments(sdk, arguments):
    if not arguments.subnet_id:
        network_id = sdk.helpers.find_network_id(folder_id=arguments.folder_id)
        arguments.subnet_id = sdk.helpers.find_subnet_id(
            folder_id=arguments.folder_id,
            zone_id=arguments.zone,
            network_id=network_id,
        )


def parse_args():
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawTextHelpFormatter)

    auth = parser.add_mutually_exclusive_group(required=True)
    auth.add_argument(
        '--sa-json-path',
        help='Path to the service account key JSON file.\nThis file can be created using YC CLI:\n'
             'yc iam key create --output sa.json --service-account-id <id>',
    )
    auth.add_argument('--token', help='OAuth token')
    parser.add_argument('--folder-id', help='Your Yandex.Cloud folder id', required=True)
    parser.add_argument(
        '--zone', default='ru-central1-b',
        help='Compute Engine zone to deploy to.')
    parser.add_argument(
        '--name', default='demo-instance', help='New instance name.')
    parser.add_argument(
        '--subnet-id', help='Subnet of the instance')

    return parser.parse_args()


if __name__ == '__main__':
    main()
